==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AInterfaceFileType.h <==
// public final class soot.jimple.parser.node.AInterfaceFileType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76555b7203e7a208 soot_jimple_parser_node_AInterfaceFileType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f319b446d60a4f41 soot_jimple_parser_node_PFileType

// header file dependencies
// @dep_header soot_jimple_parser_node_PFileType

#include "soot/jimple/parser/node/PFileType.h"

#ifndef _JC_soot_jimple_parser_node_AInterfaceFileType_H_
#define _JC_soot_jimple_parser_node_AInterfaceFileType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInterface$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs	_jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs	_jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$refs	_jc_soot_jimple_parser_node_AInterfaceFileType$refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs	_jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$object	_jc_soot_jimple_parser_node_AInterfaceFileType$object;

typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vmethods	_jc_soot_jimple_parser_node_AInterfaceFileType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtable	_jc_soot_jimple_parser_node_AInterfaceFileType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtype	_jc_soot_jimple_parser_node_AInterfaceFileType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$_init$ed49e6488d23d326(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
extern struct _jc_soot_jimple_parser_node_TInterface$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$getInterface$023ad49ca94ce5f0(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$setInterface$b8b1ec3744948e14(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$getInterface$023ad49ca94ce5f0;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$setInterface$b8b1ec3744948e14;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
	struct _jc_soot_jimple_parser_node_TInterface$object	*(*getInterface$023ad49ca94ce5f0)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setInterface$b8b1ec3744948e14)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFileType$vmethods	soot_jimple_parser_node_PFileType;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vmethods	soot_jimple_parser_node_AInterfaceFileType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs {
	struct _jc_soot_jimple_parser_node_TInterface$object	*__5finterface__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$refs {
    _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs	soot_jimple_parser_node_AInterfaceFileType;
    _jc_soot_jimple_parser_node_PFileType$sub_refs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFileType$sub_nonrefs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs	soot_jimple_parser_node_AInterfaceFileType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInterfaceFileType$object {
	_jc_soot_jimple_parser_node_AInterfaceFileType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInterfaceFileType$vtype _jc_soot_jimple_parser_node_AInterfaceFileType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInterfaceFileType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInterfaceFileType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInterfaceFileType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AInterfaceFileType.h <==
// public final class soot.jimple.parser.node.AInterfaceFileType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76555b7203e7a208 soot_jimple_parser_node_AInterfaceFileType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f319b446d60a4f41 soot_jimple_parser_node_PFileType

// header file dependencies
// @dep_header soot_jimple_parser_node_PFileType

#include "soot/jimple/parser/node/PFileType.h"

#ifndef _JC_soot_jimple_parser_node_AInterfaceFileType_H_
#define _JC_soot_jimple_parser_node_AInterfaceFileType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInterface$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs	_jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs	_jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$refs	_jc_soot_jimple_parser_node_AInterfaceFileType$refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs	_jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceFileType$object	_jc_soot_jimple_parser_node_AInterfaceFileType$object;

typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vmethods	_jc_soot_jimple_parser_node_AInterfaceFileType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtable	_jc_soot_jimple_parser_node_AInterfaceFileType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtype	_jc_soot_jimple_parser_node_AInterfaceFileType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$_init$ed49e6488d23d326(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TInterface$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$getInterface$023ad49ca94ce5f0(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceFileType$method$setInterface$b8b1ec3744948e14(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInterfaceFileType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$getInterface$023ad49ca94ce5f0;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$setInterface$b8b1ec3744948e14;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceFileType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TInterface$object	*(*getInterface$023ad49ca94ce5f0)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setInterface$b8b1ec3744948e14)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *, struct _jc_soot_jimple_parser_node_TInterface$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceFileType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFileType$vmethods	soot_jimple_parser_node_PFileType;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vmethods	soot_jimple_parser_node_AInterfaceFileType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInterfaceFileType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs {
	struct _jc_soot_jimple_parser_node_TInterface$object	*__5finterface__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$refs {
    _jc_soot_jimple_parser_node_AInterfaceFileType$sub_refs	soot_jimple_parser_node_AInterfaceFileType;
    _jc_soot_jimple_parser_node_PFileType$sub_refs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFileType$sub_nonrefs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_AInterfaceFileType$sub_nonrefs	soot_jimple_parser_node_AInterfaceFileType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInterfaceFileType$object {
	_jc_soot_jimple_parser_node_AInterfaceFileType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInterfaceFileType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInterfaceFileType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInterfaceFileType$vtype _jc_soot_jimple_parser_node_AInterfaceFileType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInterfaceFileType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInterfaceFileType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInterfaceFileType_H_ */
